Eddy-footprint documentation
=============================

A Python library for creating eddy covariance flux footprints using multiple analytical models.

Installation
------------

eddy-footprint can be installed from PyPI as:

    python -m pip install eddy_footprint

Or from source as:

    python -m pip install git+https://github.com/arctic-carbon/eddy-footprint.git

.. note::
   The required dependencies installed with eddy-footprint are `Xarray <https://xarray.dev/>`_,
   `SciPy <https://www.scipy.org/>`_, and `NumPy <https://numpy.org/>`_.

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: For users

   API Reference <api>
   Tutorials and Presentations <tutorials-and-presentations>
